@@ -32,7 +32,7 @@ void top_register_actions()
 
 void top_output_header(char* title, Project* project)
 {
-    String* base_url_a = string_new(0);
+    String* base_url_a = string_new();
     base_url_a = get_base_url(base_url_a);
     o("Pragma: no-cache\r\n");
     o("Cache-Control: no-cache\t\n");
@@ -50,19 +50,22 @@ void top_output_header(char* title, Project* project)
     o(      "</head>\n"
             "<body>\n"
             "<a name=\"top\"></a>\n"
-            "<h1 id=\"toptitle\" title=\"Starbug1\">"); h(string_rawstr(project->name)); o(" プロジェクトの管理</h1>\n");
+            "<h1 id=\"toptitle\" title=\"Starbug1\">"); h(string_rawstr(project->name)); o(" %s</h1>\n", _("project management"));
 /*             "<h1 id=\"toptitle\" title=\"Starbug1\"><a href=\"http://starbug1.sourceforge.jp/\"><img src=\"%s/../img/starbug1.jpg\" alt=\"Starbug1\" /></a></h1>\n", cgiScriptName); */
     o(      "<div id=\"projectmenu\">\n"
             "\t<ul>\n");
-    o(      "\t\t<li><a href=\"%s/../index.%s/%s/\">プロジェクトトップ</a></li>\n", cgiScriptName, get_ext(cgiScriptName), g_project_name_4_url);
-    o(      "\t\t<li><a href=\"%s/../admin.%s/%s/\">プロジェクトの管理</a></li>\n", cgiScriptName, get_ext(cgiScriptName), g_project_name_4_url);
+    o(      "\t\t<li><a href=\"%s/../index.%s/%s/\">%s</a></li>\n", cgiScriptName, get_ext(cgiScriptName), g_project_code_4_url, _("project top"));
+    o(      "\t\t<li><a href=\"%s/../admin.%s/%s/\">%s</a></li>\n", cgiScriptName, get_ext(cgiScriptName), g_project_code_4_url, _("project management"));
     o(      "\t</ul>\n"
-            "</div>\n");
+            "</div>\n"
+            "<br clear=\"all\" />\n"
+            "<div id=\"main-content\">");
 }
 void top_output_footer()
 {
     /* Finish up the page */
-    o(      "<div id=\"footer\">\n"
+    o(      "</div>\n"
+            "<div id=\"footer\">\n"
             "<hr />\n"
             "<div align=\"right\">\n"
             "<p>\n"
@@ -94,12 +97,15 @@ void top_top_action()
     char** multi;
     Project* project_a = project_new();
 
+    d("top_top_action\n");
     list_alloc(project_infos_a, ProjectInfo, project_info_new, project_info_free);
 
-    db_a = db_init(db_top_get_project_db_name(g_project_name, buffer));
+    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
     project_infos_a = db_top_get_all_project_infos(db_a, project_infos_a);
     project_a = db_get_project(db_a, project_a);
-    top_output_header("プロジェクトの管理", project_a);
+    d("top_top_action\n");
+    top_output_header(_("project management"), project_a);
+    d("top_top_action\n");
     /* メッセージの取得 */
     if ((cgiFormStringMultiple("message", &multi)) != cgiFormNotFound) {
         int i = 0;
@@ -118,37 +124,41 @@ void top_top_action()
     }
     cgiStringArrayFree(multi);
     o(      "<div id=\"project_info\">\n"
-            "\t<h2>プロジェクト情報の設定</h2>\n");
+            "\t<h2>%s</h2>\n", _("project information settings"));
     o(      "\t<form action=\"%s/top/top_update_project_info_submit\" method=\"post\">\n", cgiScriptName);
     o(      "\t\t<table>\n"
             "\t\t\t<tr>\n"
-            "\t\t\t\t<th>プロジェクト名</th>\n"
-            "\t\t\t\t<td><input type=\"text\" name=\"project.name\" value=\""); v(string_rawstr(project_a->name)); o("\" maxlength=\"1000\" /></td>\n"
+            "\t\t\t\t<th>%s</th>\n"
+            "\t\t\t\t<td><input type=\"text\" name=\"project.name\" value=\"", _("project name")); v(string_rawstr(project_a->name)); o("\" maxlength=\"1000\" /></td>\n"
             "\t\t\t</tr>\n"
             "\t\t\t<tr>\n"
-            "\t\t\t\t<th>ホームリンク名</th>\n"
-            "\t\t\t\t<td><input type=\"text\" name=\"project.home_description\" value=\""); v(string_rawstr(project_a->home_description)); o("\" maxlength=\"1000\" /></td>\n"
+            "\t\t\t\t<th>%s</th>\n", _("home link name"));
+    o(      "\t\t\t\t<td><input type=\"text\" name=\"project.home_description\" value=\""); v(string_rawstr(project_a->home_description)); o("\" maxlength=\"1000\" /></td>\n"
             "\t\t\t</tr>\n"
             "\t\t\t<tr>\n"
-            "\t\t\t\t<th>ホームリンク先</th>\n"
-            "\t\t\t\t<td><input type=\"text\" name=\"project.home_url\" value=\""); v(string_rawstr(project_a->home_url)); o("\" maxlength=\"1000\" /></td>\n"
+            "\t\t\t\t<th>%s</th>\n", _("home link refference"));
+    o(      "\t\t\t\t<td><input type=\"text\" name=\"project.home_url\" value=\""); v(string_rawstr(project_a->home_url)); o("\" maxlength=\"1000\" /></td>\n"
+            "\t\t\t</tr>\n");
+    o(      "\t\t\t<tr>\n"
+            "\t\t\t\t<th>%s</th>\n", _("locale"));
+    o(      "\t\t\t\t<td><input type=\"text\" name=\"project.locale\" value=\""); v(string_rawstr(project_a->locale)); o("\" maxlength=\"5\" /></td>\n"
             "\t\t\t</tr>\n");
     o(      "\t\t</table>\n");
-    o(      "\t\t<input class=\"button\" type=\"submit\" value=\"更新\" />\n");
+    o(      "\t\t<input class=\"button\" type=\"submit\" value=\"%s\" />\n", _("update"));
     o(      "\t</form>\n");
     o(      "</div>\n");
     project_free(project_a);
-    o(      "<div id=\"project_list\">\n"
-            "\t<h2>サブプロジェクト一覧</h2>\n");
+    o(      "<div id=\"sub_project_list\">\n"
+            "\t<h2>%s</h2>\n", _("sub projects list"));
     o(      "\t<form action=\"%s/top/top_update_project_submit\" method=\"post\">\n", cgiScriptName);
     o(      "\t\t<table>\n"
             "\t\t\t<tr>\n"
-            "\t\t\t\t<th>サブプロジェクト名</th>\n"
-            "\t\t\t\t<th>データベースパス</th>\n"
-            "\t\t\t\t<th>サブプロジェクトID</th>\n"
-            "\t\t\t\t<th>並び順</th>\n"
-            "\t\t\t\t<th>削除</th>\n"
-            "\t\t\t</tr>\n");
+            "\t\t\t\t<th>%s</th>\n"
+            "\t\t\t\t<th>%s</th>\n"
+            "\t\t\t\t<th>%s</th>\n"
+            "\t\t\t\t<th>%s</th>\n"
+            "\t\t\t\t<th>%s</th>\n"
+            "\t\t\t</tr>\n", _("sub project name"), _("database path"), _("sub project id"), _("sort"), _("delete"));
     foreach (it, project_infos_a) {
         ProjectInfo* p = it->element;
         Database* db_project_a;
@@ -167,34 +177,34 @@ void top_top_action()
         o(      "\t\t\t\t<td>"); h(db_name); o("</td>\n");
         project_free(project_a);
         db_finish(db_project_a);
-        o(      "\t\t\t\t<td><input type=\"text\" name=\"project_%d.name\" class=\"project_id\" value=\"", p->id); h(string_rawstr(p->name)); o("\" /></td>\n");
+        o(      "\t\t\t\t<td><input type=\"text\" name=\"project_%d.code\" class=\"project_id\" value=\"", p->id); h(string_rawstr(p->code)); o("\" /></td>\n");
         o(      "\t\t\t\t<td><input type=\"text\" name=\"project_%d.sort\" class=\"number\" value=\"%d\" /></td>\n", p->id, p->sort);
         o(      "\t\t\t\t<td><input type=\"checkbox\" class=\"checkbox\" name=\"project_%d.deleted\" id=\"project_%d.deleted\" value=\"1\" %s /></td>\n", p->id, p->id, p->deleted ? "checked=\"checked\"" : "");
         o(      "\t\t\t</tr>\n");
     }
     list_free(project_infos_a);
     o(      "\t\t</table>\n");
-    o(      "\t\t<p>サブプロジェクト名は各サブプロジェクトの管理ツールから設定してください。</p>\n");
-    o(      "\t\t<p>既存のサブプロジェクトIDを変更すると、サブプロジェクトのURLが変わってしまうので注意してください。</p>\n");
-    o(      "\t\t<p>削除すると、トップページの一覧から表示されなくなります。データは消去されません。再度削除チェックボックスのチェックを外すことで、再び参照することができるようになります。</p>\n");
-    o(      "\t\t<input class=\"button\" type=\"submit\" value=\"更新\" />\n");
+    o(      "\t\t<p>%s</p>\n", _("[project settings description1]"));
+    o(      "\t\t<p>%s</p>\n", _("[project settings description2]"));
+    o(      "\t\t<p>%s</p>\n", _("[project settings description3]"));
+    o(      "\t\t<input class=\"button\" type=\"submit\" value=\"%s\" />\n", _("update"));
     o(      "\t</form>\n");
     o(      "\t</div>\n");
     o(      "\t<div id=\"project_add\">\n"
-            "\t\t<h2>サブプロジェクトの追加</h2>\n");
+            "\t\t<h2>%s</h2>\n", _("add sub project"));
     o(      "\t\t<form action=\"%s/top/top_add_project_submit\" method=\"post\">\n", cgiScriptName);
     o(      "\t\t\t<table>\n"
             "\t\t\t\t<tr>\n"
-            "\t\t\t\t\t<th>サブプロジェクトID</th>\n"
-            "\t\t\t\t\t<th>並び順</th>\n"
-            "\t\t\t\t</tr>\n"
-            "\t\t\t\t<tr>\n"
-            "\t\t\t\t\t<td><input type=\"text\" name=\"project_new.name\" class=\"project_id\" value=\"\" /></td>\n"
+            "\t\t\t\t\t<th>%s</th>\n"
+            "\t\t\t\t\t<th>%s</th>\n"
+            "\t\t\t\t</tr>\n", _("sub project id"), _("sort"));
+    o(      "\t\t\t\t<tr>\n"
+            "\t\t\t\t\t<td><input type=\"text\" name=\"project_new.code\" class=\"project_id\" value=\"\" /></td>\n"
             "\t\t\t\t\t<td><input type=\"text\" name=\"project_new.sort\" class=\"number\" value=\"\" /></td>\n");
     o(      "\t\t\t\t</tr>\n");
     o(      "\t\t\t</table>\n");
-    o(      "\t\t\t<p>サブプロジェクト名は各サブプロジェクトの管理ツールから設定してください。</p>\n");
-    o(      "\t\t\t<input class=\"button\" type=\"submit\" value=\"追加\" />\n");
+    o(      "\t\t\t<p>%s</p>\n", _("[sub project name description]"));
+    o(      "\t\t\t<input class=\"button\" type=\"submit\" value=\"%s\" />\n", _("add"));
     o(      "\t\t</form>\n");
     o(      "\t</div>\n");
     top_output_footer();
@@ -205,11 +215,12 @@ void top_update_project_info_submit_action()
     Database* db_a;
     char buffer[DEFAULT_LENGTH];
 
-    db_a = db_init(db_top_get_project_db_name(g_project_name, buffer));
+    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
     {
         char name[DEFAULT_LENGTH];
         char home_description[DEFAULT_LENGTH];
         char home_url[DEFAULT_LENGTH];
+        char locale[16];
         Project* project_a = project_new();
 
         d("db->name: %s\n", db_a->name);
@@ -219,14 +230,16 @@ void top_update_project_info_submit_action()
         string_set(project_a->home_description, home_description);
         cgiFormString("project.home_url", home_url, DEFAULT_LENGTH);
         string_set(project_a->home_url, home_url);
+        cgiFormString("project.locale", locale, 16);
+        string_set(project_a->locale, locale);
         db_top_update_project(db_a, project_a);
         project_free(project_a);
     }
     db_finish(db_a);
 
-    redirect("", "修正しました。");
+    redirect("", _("updated."));
 }
-static bool validate_project_id_exists(Database* db, char* name, int id)
+static bool validate_project_code_exists(Database* db, char* code, int id)
 {
     bool ret = true;
     List* project_infos_a;
@@ -236,7 +249,7 @@ static bool validate_project_id_exists(Database* db, char* name, int id)
     foreach (it, project_infos_a) {
         ProjectInfo* p = it->element;
         if (p->id == id) continue;
-        if (strcmp(name, string_rawstr(p->name)) == 0) {
+        if (strcmp(code, string_rawstr(p->code)) == 0) {
             ret = false;
             break;
         }
@@ -244,7 +257,7 @@ static bool validate_project_id_exists(Database* db, char* name, int id)
     list_free(project_infos_a);
     return ret;
 }
-static bool validate_project_id(char* name)
+static bool validate_project_code(char* name)
 {
     if (strcmp(name, "top") == 0) {
         return false;
@@ -256,7 +269,7 @@ void top_update_project_submit_action()
     Database* db_a;
     char buffer[DEFAULT_LENGTH];
 
-    db_a = db_init(db_top_get_project_db_name(g_project_name, buffer));
+    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
     {
         List* project_infos_a;
         Iterator* it;
@@ -265,29 +278,29 @@ void top_update_project_submit_action()
         project_infos_a = db_top_get_all_project_infos(db_a, project_infos_a);
         foreach (it, project_infos_a) {
             ProjectInfo* p = it->element;
-            char name[DEFAULT_LENGTH];
+            char code[DEFAULT_LENGTH];
             char sort[DEFAULT_LENGTH];
             char deleted[DEFAULT_LENGTH];
             char param_name[DEFAULT_LENGTH];
             if (p->id == 1) continue; /* topは更新対象外 */ 
 
-            sprintf(param_name, "project_%d.name", p->id);
-            cgiFormString(param_name, name, DEFAULT_LENGTH);
-            if (!validate_project_id(name)) {
+            sprintf(param_name, "project_%d.code", p->id);
+            cgiFormString(param_name, code, DEFAULT_LENGTH);
+            if (!validate_project_code(code)) {
                 list_free(project_infos_a);
                 db_finish(db_a);
-                redirect("", "[ERROR] プロジェクトID topは予約されています。");
+                redirect("", _("[error] projectid top is reserved."));
                 return;
             }
-            if (!validate_project_id_exists(db_a, name, p->id)) {
+            if (!validate_project_code_exists(db_a, code, p->id)) {
                 char message[DEFAULT_LENGTH];
                 list_free(project_infos_a);
                 db_finish(db_a);
-                sprintf(message, "[ERROR] プロジェクトID %sは既に存在しています。", name);
+                sprintf(message, "%s %s %s", _("[error] projectid("), code, _(") is already exists."));
                 redirect("", message);
                 return;
             }
-            string_set(p->name, name);
+            string_set(p->code, code);
             sprintf(param_name, "project_%d.sort", p->id);
             cgiFormString(param_name, sort, DEFAULT_LENGTH);
             p->sort = atoi(sort);
@@ -304,36 +317,36 @@ void top_update_project_submit_action()
     }
     db_finish(db_a);
 
-    redirect("", "更新しました。");
+    redirect("", _("updated."));
 }
 void top_add_project_submit_action()
 {
     Database* db_a;
     char buffer[DEFAULT_LENGTH];
 
-    db_a = db_init(db_top_get_project_db_name(g_project_name, buffer));
+    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
     {
-        char name[DEFAULT_LENGTH];
+        char code[DEFAULT_LENGTH];
         char sort[DEFAULT_LENGTH];
         ProjectInfo* pi_a = project_info_new();
 
         d("db->name: %s\n", db_a->name);
-        cgiFormString("project_new.name", name, DEFAULT_LENGTH);
-        if (!validate_project_id(name)) {
+        cgiFormString("project_new.code", code, DEFAULT_LENGTH);
+        if (!validate_project_code(code)) {
             project_info_free(pi_a);
             db_finish(db_a);
-            redirect("", "[ERROR] プロジェクトID topは予約されています。");
+            redirect("", _("[error] projectid top is reserved."));
             return;
         }
-        if (!validate_project_id_exists(db_a, name, 0)) {
+        if (!validate_project_code_exists(db_a, code, 0)) {
             char message[DEFAULT_LENGTH];
             project_info_free(pi_a);
             db_finish(db_a);
-            sprintf(message, "[ERROR] プロジェクトID %sは既に存在しています。", name);
+            sprintf(message, "%s %s %s", _("[error] projectid("), code, _(") is already exists."));
             redirect("", message);
             return;
         }
-        string_set(pi_a->name, name);
+        string_set(pi_a->code, code);
         cgiFormString("project_new.sort", sort, DEFAULT_LENGTH);
         pi_a->sort = atoi(sort);
         db_top_register_project_info(db_a, pi_a);
@@ -341,6 +354,6 @@ void top_add_project_submit_action()
     }
     db_finish(db_a);
 
-    redirect("", "追加しました。");
+    redirect("", _("added."));
 }
 /* vim: set ts=4 sw=4 sts=4 expandtab fenc=utf-8: */
