@@ -21,7 +21,7 @@ typedef enum _bool {
 
 typedef struct {
     int id;
-    String* name;
+    String* code;
     int sort;
     int deleted;
 } ProjectInfo;
@@ -33,6 +33,7 @@ typedef struct {
     String* home_description;
     String* home_url;
     int upload_max_size;
+    String* locale;
 } Project;
 Project* project_new();
 void project_free(Project*);
@@ -129,7 +130,8 @@ typedef struct {
 enum CONDITION_TYPE {
     CONDITION_TYPE_NORMAL,
     CONDITION_TYPE_DATE_FROM,
-    CONDITION_TYPE_DATE_TO
+    CONDITION_TYPE_DATE_TO,
+    CONDITION_TYPE_DAYS
 };
 Condition* condition_new();
 void condition_free(Condition*);
@@ -169,7 +171,20 @@ char* get_element_value(List*, ElementType*);
 // int get_element_lid_by_id(List*, int);
 void set_element_value(Element*, const char*);
 
+typedef struct {
+    int project_id;
+    String* project_code;
+    String* project_name;
+    int id;
+    String* title;
+} Ticket;
+Ticket* ticket_new();
+void ticket_free(Ticket*);
 
+typedef struct {
+    int id;
+    int field_count;
+} DbInfo;
 
 #endif
 /* vim: set ts=4 sw=4 sts=4 expandtab fenc=utf-8: */
