@@ -12,18 +12,30 @@
 
 void create_columns_exp(List*, char*, char*);
 
-static List* db_get_element_types(Database* db, bool all, List* element_types)
+static List* db_get_element_types(Database* db, DbInfo* db_info, bool all, List* element_types)
 {
     int r;
-    const char *sql;
+    String* sql_a = string_new();
     sqlite3_stmt *stmt = NULL;
+    char db_id[10] = "";
 
-    if (all) {
-        sql = "select id, type, ticket_property, reply_property, required, name, description, display_in_list, sort, default_value, auto_add_item from element_type where deleted = 0 order by sort";
-    } else {
-        sql = "select id, type, ticket_property, reply_property, required, name, description, display_in_list, sort, default_value, auto_add_item from element_type where deleted = 0 and display_in_list = 1 order by sort";
+    if (db_info) {
+        sprintf(db_id, "db%d.", db_info->id);
     }
-    if (sqlite3_prepare(db->handle, sql, strlen(sql), &stmt, NULL) == SQLITE_ERROR) goto error;
+    if (all) {
+        string_appendf(sql_a,
+                "select id, type, ticket_property, reply_property, required, name, "
+                "  description, display_in_list, sort, default_value, auto_add_item "
+                "from %selement_type "
+                "where deleted = 0 order by sort", db_id);
+    } else {
+        string_appendf(sql_a,
+                "select id, type, ticket_property, reply_property, required, name, "
+                "  description, display_in_list, sort, default_value, auto_add_item "
+                "from %selement_type "
+                "where deleted = 0 and display_in_list = 1 order by sort", db_id);
+    }
+    if (sqlite3_prepare(db->handle, string_rawstr(sql_a), string_len(sql_a), &stmt, NULL) == SQLITE_ERROR) goto error;
     sqlite3_reset(stmt);
 
     while (SQLITE_ROW == (r = sqlite3_step(stmt))){
@@ -49,19 +61,28 @@ static List* db_get_element_types(Database* db, bool all, List* element_types)
     if (SQLITE_DONE != r)
         goto error;
 
+    string_free(sql_a);
     sqlite3_finalize(stmt);
 
     return element_types;
 
 ERROR_LABEL(db->handle)
 }
-List* db_get_element_types_4_list(Database* db, List* elements)
+/*
+ * 引数のdb_infoは、index_top.cから呼び出すようになったために追加した引数。
+ * その他から呼び出す場合は、NULLを指定する。
+ */
+List* db_get_element_types_4_list(Database* db, DbInfo* db_info, List* elements)
 {
-    return db_get_element_types(db, false, elements);
+    return db_get_element_types(db, db_info, false, elements);
 }
-List* db_get_element_types_all(Database* db, List* elements)
+/*
+ * 引数のdb_infoは、index_top.cから呼び出すようになったために追加した引数。
+ * その他から呼び出す場合は、NULLを指定する。
+ */
+List* db_get_element_types_all(Database* db, DbInfo* db_info, List* elements)
 {
-    return db_get_element_types(db, true, elements);
+    return db_get_element_types(db, db_info, true, elements);
 }
 ElementType* db_get_element_type(Database* db, int id, ElementType* e)
 {
@@ -130,6 +151,27 @@ List* db_get_list_item(Database* db, const int element_type, List* items)
 ERROR_LABEL(db->handle)
 }
 
+int db_get_list_item_id(Database* db, const int element_type, char* name)
+{
+    int r, id = 0;
+    const char *sql = "select id from list_item where element_type_id = ? and name = ?";
+    sqlite3_stmt *stmt = NULL;
+
+    if (sqlite3_prepare(db->handle, sql, strlen(sql), &stmt, NULL) == SQLITE_ERROR) goto error;
+    sqlite3_reset(stmt);
+    sqlite3_bind_int(stmt, 1, element_type);
+    sqlite3_bind_text(stmt, 2, name, strlen(name), NULL);
+
+    if (SQLITE_ROW == (r = sqlite3_step(stmt))) {
+        id = sqlite3_column_int(stmt, 0);
+    }
+
+    sqlite3_finalize(stmt);
+
+    return id;
+
+ERROR_LABEL(db->handle)
+}
 void create_message_insert_sql(List* elements, char* buf)
 {
     Iterator* it;
@@ -267,48 +309,6 @@ int db_register_ticket(Database* db, Message* ticket)
 ERROR_LABEL(db->handle)
 }
 
-static String* create_columns_like_exp(List* element_types, char* table_name, List* keywords, String* buf)
-{
-    Iterator* it_keyword;
-    Iterator* it;
-    foreach (it_keyword, keywords) {
-        foreach (it, element_types) {
-            char column_name[DEFAULT_LENGTH];
-            ElementType* et = it->element;
-            if (string_len(buf))
-                string_append(buf, "or ");
-            sprintf(column_name, "%s.field%d like '%%' || ? || '%%' ", table_name, et->id);
-            string_append(buf, column_name);
-        }
-    }
-    return buf;
-}
-static List* parse_keywords(List* keywords, char* query)
-{
-    char* hit;
-    char* p = query;
-    if (strlen(p) == 0) {
-        return keywords;
-    }
-    while (1) {
-        hit = strchr(p, ' ');
-        if (hit == NULL) {
-            char* word = xalloc(sizeof(char) * strlen(p) + 1);
-            strcpy(word, p);
-            if (strlen(word))
-                list_add(keywords, word);
-            break;
-        } else {
-            int len = hit - p + 1;
-            char* word = xalloc(len);
-            strncpy(word, p, len - 1);
-            p = hit + 1;
-            if (strlen(word))
-                list_add(keywords, word);
-        }
-    }
-    return keywords;
-}
 static String* get_search_sql_string(Database* db, List* conditions, Condition* sort, List* keywords, String* sql_string)
 {
     int i = 0;
@@ -354,7 +354,7 @@ static String* get_search_sql_string(Database* db, List* conditions, Condition*
             char name[DEFAULT_LENGTH];
             char val[DEFAULT_LENGTH];
             if (cond->element_type_id > 0) continue;
-            if (string_len(cond->value) == 0) continue;
+            if (!valid_condition(cond)) continue;
             if (i++) string_append(sql_string, " and ");
             switch (cond->element_type_id) {
                 case ELEM_ID_REGISTERDATE:
@@ -371,6 +371,11 @@ static String* get_search_sql_string(Database* db, List* conditions, Condition*
                 case CONDITION_TYPE_DATE_TO:
                     sprintf(val, " (%s <= ?) ", name);
                     break;
+                case CONDITION_TYPE_DAYS:
+                    sprintf(val, " (%s >= datetime(current_timestamp, 'utc', '-%s days', 'localtime')) ",
+                            name,
+                            get_condition_valid_value(cond));
+                    break;
             }
             string_append(sql_string, val);
         }
@@ -379,7 +384,7 @@ static String* get_search_sql_string(Database* db, List* conditions, Condition*
         String* columns_a = string_new(0);
         List* element_types_a;
         list_alloc(element_types_a, ElementType, element_type_new, element_type_free);
-        element_types_a = db_get_element_types_all(db, element_types_a);
+        element_types_a = db_get_element_types_all(db, NULL, element_types_a);
         columns_a = create_columns_like_exp(element_types_a, "m_all", keywords, columns_a);
         if (valid_condition_size(conditions))
             string_append(sql_string, " and ");
@@ -426,6 +431,7 @@ int set_conditions(Database* db, sqlite3_stmt* stmt, List* conditions, List* key
         Condition* cond = it->element;
         char* v;
         if (!valid_condition(cond)) continue;
+        if (cond->condition_type == CONDITION_TYPE_DAYS) continue; /* プレースフォルダが無いためスルーする */
         v = get_condition_valid_value(cond);
         sqlite3_bind_text(stmt, n++, v, strlen(v), NULL);
     }
@@ -434,11 +440,11 @@ int set_conditions(Database* db, sqlite3_stmt* stmt, List* conditions, List* key
         Iterator* it_keyword;
         Iterator* it;
         list_alloc(element_types_a, ElementType, element_type_new, element_type_free);
-        element_types_a = db_get_element_types_all(db, element_types_a);
+        element_types_a = db_get_element_types_all(db, NULL, element_types_a);
         foreach (it_keyword, keywords) {
-            char* word = it_keyword->element;
+            String* word = it_keyword->element;
             foreach (it, element_types_a) {
-                sqlite3_bind_text(stmt, n++, word, strlen(word), NULL);
+                sqlite3_bind_text(stmt, n++, string_rawstr(word), string_len(word), NULL);
             }
         }
         list_free(element_types_a);
@@ -448,7 +454,7 @@ int set_conditions(Database* db, sqlite3_stmt* stmt, List* conditions, List* key
 SearchResult* db_get_tickets_by_status(Database* db, const char* status, SearchResult* result)
 {
     int r, n, hit_count = 0;
-    String* sql_a = string_new(0);
+    String* sql_a = string_new();
     List* conditions;
     Condition* cond_status;
     sqlite3_stmt *stmt = NULL;
@@ -491,11 +497,11 @@ ERROR_LABEL(db->handle)
 SearchResult* db_search_tickets(Database* db, List* conditions, char* q, Condition* sorts, const int page, SearchResult* result)
 {
     int r, n;
-    String* sql_a = string_new(0);
+    String* sql_a = string_new();
     sqlite3_stmt *stmt = NULL;
     List* keywords_a;
 
-    list_alloc(keywords_a, char, NULL, NULL);
+    list_alloc(keywords_a, String, string_new, string_free);
     keywords_a = parse_keywords(keywords_a, q);
     sql_a = get_search_sql_string(db, conditions, sorts, keywords_a, sql_a);
 
@@ -518,7 +524,7 @@ SearchResult* db_search_tickets(Database* db, List* conditions, char* q, Conditi
     string_free(sql_a);
     /* hit件数を取得する。 */
     {
-        String* s = string_new(0);
+        String* s = string_new();
         string_append(s, "select count(res.id), res.state from (");
         s = get_search_sql_string(db, conditions, sorts, keywords_a, s);
         string_appendf(s,
@@ -550,11 +556,11 @@ ERROR_LABEL(db->handle)
 SearchResult* db_search_tickets_4_report(Database* db, List* conditions, char* q, Condition* sorts, SearchResult* result)
 {
     int r, n;
-    String* sql_a = string_new(0);
+    String* sql_a = string_new();
     sqlite3_stmt *stmt = NULL;
     List* keywords_a;
 
-    list_alloc(keywords_a, char, NULL, NULL);
+    list_alloc(keywords_a, String, string_new, string_free);
     keywords_a = parse_keywords(keywords_a, q);
     sql_a = get_search_sql_string(db, conditions, sorts, keywords_a, sql_a);
 
@@ -606,7 +612,7 @@ List* db_get_last_elements_4_list(Database* db, const int ticket_id, List* eleme
     Iterator* it;
 
     list_alloc(element_types_a, ElementType, element_type_new, element_type_free);
-    element_types_a = db_get_element_types_4_list(db, element_types_a);
+    element_types_a = db_get_element_types_4_list(db, NULL, element_types_a);
     create_columns_exp(element_types_a, "last_m", columns);
     sprintf(sql, "select t.id, org_m.field%d ", ELEM_ID_SENDER);
     strcat(sql, columns);
@@ -676,7 +682,7 @@ List* db_get_last_elements(Database* db, const int ticket_id, List* elements)
     char columns[DEFAULT_LENGTH] = "";
 
     list_alloc(element_types_a, ElementType, element_type_new, element_type_free);
-    element_types_a = db_get_element_types_all(db, element_types_a);
+    element_types_a = db_get_element_types_all(db, NULL, element_types_a);
     create_columns_exp(element_types_a, "m", columns);
     strcpy(sql, "select m.id");
     strcat(sql, columns);
@@ -741,7 +747,7 @@ List* db_get_elements(Database* db, int message_id, List* elements)
     List* element_types_a = NULL;
 
     list_alloc(element_types_a, ElementType, element_type_new, element_type_free);
-    element_types_a = db_get_element_types_all(db, element_types_a);
+    element_types_a = db_get_element_types_all(db, NULL, element_types_a);
     create_columns_exp(element_types_a, "m", columns);
 
     strcpy(sql, "select m.registerdate");
@@ -833,6 +839,8 @@ Project* db_get_project(Database* db, Project* project)
             string_set(project->home_url, (char*)sqlite3_column_text(stmt, 1));
         else if (strcmp(name, "upload_max_size") == 0)
             project->upload_max_size = sqlite3_column_int(stmt, 1);
+        else if (strcmp(name, "locale") == 0)
+            string_set(project->locale, (char*)sqlite3_column_text(stmt, 1));
     }
     /* アップロードファイルサイズの上限値が有効な値でない場合は、512kbを設定する。 */
     project->upload_max_size = (project->upload_max_size <= 0) ? 512 : project->upload_max_size;
