@@ -17,6 +17,7 @@
 void top_top_action();
 void top_edit_top_action();
 void top_edit_top_submit_action();
+void top_search_action();
 
 /* prototype declares */
 int index_top_main();
@@ -26,6 +27,7 @@ void top_register_actions()
     REG_ACTION(top_top);
     REG_ACTION(top_edit_top);
     REG_ACTION(top_edit_top_submit);
+    REG_ACTION(top_search);
 }
 
 void top_output_header(char* title, Project* project)
@@ -50,15 +52,18 @@ void top_output_header(char* title, Project* project)
     o(      "<div id=\"projectmenu\">\n"
             "\t<ul>\n"
             "\t\t<li><a href=\""); h(string_rawstr(project->home_url)); o("\">"); h(string_rawstr(project->home_description)); o("</a></li>\n");
-    o(      "\t\t<li><a href=\"%s/../index.%s/%s/\">プロジェクトトップ</a></li>\n", cgiScriptName, get_ext(cgiScriptName), g_project_name_4_url);
-    o(      "\t\t<li><a href=\"%s/../admin.%s/%s/\">プロジェクトの管理</a></li>\n", cgiScriptName, get_ext(cgiScriptName), g_project_name_4_url);
+    o(      "\t\t<li><a href=\"%s/../index.%s/%s/\">%s</a></li>\n", cgiScriptName, get_ext(cgiScriptName), g_project_code_4_url, _("project top"));
+    o(      "\t\t<li><a href=\"%s/../admin.%s/%s/\">%s</a></li>\n", cgiScriptName, get_ext(cgiScriptName), g_project_code_4_url, _("project management"));
     o(      "\t</ul>\n");
-    o(      "</div>\n");
+    o(      "</div>\n"
+            "<br clear=\"all\" />\n"
+            "<div id=\"main-content\">");
 }
 void top_output_footer()
 {
     /* Finish up the page */
-    o(      "<div id=\"footer\">\n"
+    o(      "</div>\n"
+            "<div id=\"footer\">\n"
             "<hr />\n"
             "<div align=\"right\">\n"
             "<p>\n"
@@ -91,13 +96,13 @@ void top_top_action()
 
     list_alloc(project_infos_a, ProjectInfo, project_info_new, project_info_free);
 
-    db_a = db_init(db_top_get_project_db_name(g_project_name, buffer));
+    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
     project_infos_a = db_top_get_all_project_infos(db_a, project_infos_a);
     top_project_a = db_get_project(db_a, top_project_a);
-    top_output_header("トップページ", top_project_a);
+    top_output_header(_("top page"), top_project_a);
     o(      "<div id=\"project_list\">\n"
-            "\t<h2>サブプロジェクト一覧</h2>\n"
-            "\t<ul>\n");
+            "\t<h2>%s</h2>\n"
+            "\t<ul>\n", _("sub projects list"));
     foreach (it, project_infos_a) {
         ProjectInfo* p = it->element;
         Database* db_project_a;
@@ -114,16 +119,23 @@ void top_top_action()
         sprintf(db_name, "db/%d.db", p->id);
         db_project_a = db_init(db_name);
         project_a = db_get_project(db_project_a, project_a);
-        o(      "\t\t\t\t<li><a href=\"%s/", cgiScriptName); u(string_rawstr(p->name)); o("\">"); h(string_rawstr(project_a->name)); o("</a></li>\n");
+        o(      "\t\t\t\t<li><a href=\"%s/", cgiScriptName); u(string_rawstr(p->code)); o("\">"); h(string_rawstr(project_a->name)); o("</a></li>\n");
         project_free(project_a);
         db_finish(db_project_a);
     }
     list_free(project_infos_a);
     o(      "\t</ul>\n");
+    o(      "\t<h2>%s</h2>\n"
+            "\t<form action=\"%s/%s/top_search\" method=\"get\">\n", _("search"), cgiScriptName, g_project_code_4_url);
+    o(      "\t\t<div>%s</div>\n", _("search by keyword for all sub projects."));
+    o(      "\t\t<input type=\"text\" name=\"q\" />\n"
+            "\t\t<input type=\"submit\" value=\"%s\" />\n"
+            "\t</form>\n", _("search"));
+
     o(      "</div>\n");
     o(      "<div id=\"dashboard\">\n"
-            "\t<h2>説明</h2>\n");
-    o(      "<a href=\"%s/%s/top_edit_top\">ページの編集</a>\n", cgiScriptName, g_project_name_4_url);
+            "\t<h2>%s</h2>\n", _("description"));
+    o(      "<a href=\"%s/%s/top_edit_top\">%s</a>\n", cgiScriptName, g_project_code_4_url, _("edit top page"));
     wiki_out(db_a, "top");
     d("pass wiki_out end\n");
     o(      "</div>\n");
@@ -138,51 +150,23 @@ void top_edit_top_action()
     char buffer[DEFAULT_LENGTH];
     Project* project_a = project_new();
 
-    db_a = db_init(db_top_get_project_db_name(g_project_name, buffer));
+    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
     project_a = db_get_project(db_a, project_a);
-    top_output_header("ページの編集", project_a);
+    top_output_header(_("edit page"), project_a);
     project_free(project_a);
-    o(      "<h2>ページの編集</h2>\n"
+    o(      "<h2>%s</h2>\n"
             "<div id=\"top\">\n"
-            "<h3>ページの編集</h3>\n"
-            "<div id=\"description\">簡易wikiの文法でページのコンテンツの編集を行ない、更新ボタンを押してください。</div>\n"
-            "<form id=\"edit_top_form\" action=\"%s/%s/top_edit_top_submit\" method=\"post\">\n", cgiScriptName, g_project_name_4_url);
+            "<h3>%s</h3>\n"
+            "<div id=\"description\">%s</div>\n",
+            _("edit page"), _("edit page"), _("[wiki syntax description1]"));
+    o(      "<form id=\"edit_top_form\" action=\"%s/%s/top_edit_top_submit\" method=\"post\">\n", cgiScriptName, g_project_code_4_url);
     o(      "<textarea name=\"edit_top\" id=\"edit_top\" rows=\"3\" cols=\"10\">");
     wiki_content_out(db_a, "top");
     o(      "</textarea>\n"
             "<div>&nbsp;</div>\n"
-            "<input class=\"button\" type=\"submit\" value=\"更新\" />\n"
-            "</form>"
-            "<div>\n"
-            "<h3>簡易wikiのサポートする文法</h3>\n"
-            "<ul>\n"
-            "<li>行頭に*を記述した行は、大見出しになります。</li>\n"
-            "<li>行頭に**を記述した行は、中見出しになります。</li>\n"
-            "<li>行頭に***を記述した行は、小見出しになります。</li>\n"
-            "<li>行頭に****を記述した行は、極小見出しになります。</li>\n"
-            "<li>行頭に-を記述した行は、箇条書きになります。</li>\n"
-            "<li>行頭に----を記述した行は、区切り線になります。</li>\n"
-            "<li>行頭が >| から始まる行から、行頭が |< から始まる行までは、整形済みブロックになります。</li>\n"
-            "</ul>\n"
-            "<h5>例</h5>\n"
-            "<pre>\n"
-            "*編集可能領域\n"
-            "自由に編集できます。\n"
-            "右側の「ページの編集」のリンクから編集してください。\n"
-            "色々な用途に使用してください。\n"
-            "-お知らせ\n"
-            "-Starbug1の使い方についての注意事項など\n"
-            "\n"
-            ">|\n"
-            "void displayWidgets (Iterable<Widget> widgets) {\n"
-            "  for (Widget w : widgets) {\n"
-            "    w.display();\n"
-            "  }\n"
-            "}\n"
-            "|<\n"
-            "</pre>\n"
-            "</div>\n"
-            "</div>\n");
+            "<input class=\"button\" type=\"submit\" value=\"%s\" />\n", _("update"));
+    o(      "</form>");
+    print_wiki_help();
     db_finish(db_a);
     top_output_footer();
 }
@@ -194,11 +178,44 @@ void top_edit_top_submit_action()
     char* value_a = xalloc(sizeof(char) * VALUE_LENGTH);
 
     cgiFormString("edit_top", value_a, VALUE_LENGTH);
-    db_a = db_init(db_top_get_project_db_name(g_project_name, buffer));
+    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
     wiki_save(db_a, "top", value_a);
     db_finish(db_a);
     xfree(value_a);
 
     redirect("", NULL);
 }
+void top_search_action()
+{
+    Database* db_a;
+    char buffer[DEFAULT_LENGTH];
+    List* tickets_a;
+    Iterator* it;
+    char q[DEFAULT_LENGTH];
+    Project* top_project_a = project_new();
+
+    cgiFormStringNoNewlines("q", q, DEFAULT_LENGTH);
+    list_alloc(tickets_a, Ticket, ticket_new, ticket_free);
+
+    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    tickets_a = db_top_search(db_a, q, tickets_a);
+    top_project_a = db_get_project(db_a, top_project_a);
+    top_output_header(_("top page"), top_project_a);
+    project_free(top_project_a);
+    o(      "<div id=\"project_list\">\n"
+            "\t<h2>%s</h2>\n"
+            "\t<ul>\n", _("search result"));
+    foreach (it, tickets_a) {
+        Ticket* t = it->element;
+        o(      "\t\t\t\t<li><a href=\"%s/%s/ticket/%d", cgiScriptName, string_rawstr(t->project_code), t->id);
+        o("\">"); h(string_rawstr(t->project_name)); o(" "); h(string_rawstr(t->title)); o("</a></li>\n");
+    }
+    list_free(tickets_a);
+    o(      "</ul>\n");
+    o(      "</div>\n");
+    o(      "<br clear=\"all\">\n");
+    o(      "<div class=\"navigation\"><a href=\"%s/top/\">%s</a></div>\n", cgiScriptName, _("back to top"));
+    top_output_footer();
+    db_finish(db_a);
+}
 /* vim: set ts=4 sw=4 sts=4 expandtab fenc=utf-8: */
