@@ -4,16 +4,15 @@
 #include <time.h>
 #include <sys/time.h>
 #include <cgic.h>
-#include <iconv.h>
 #include <errno.h>
 #include "alloc.h"
 #include "conv.h"
 #include "util.h"
 #include "hook.h"
 
-/* プロジェクト名 */
-char g_project_name[DEFAULT_LENGTH] = "";
-char g_project_name_4_url[DEFAULT_LENGTH] = "";
+/* プロジェクトコード */
+char g_project_code[DEFAULT_LENGTH] = "";
+char g_project_code_4_url[DEFAULT_LENGTH] = "";
 /* アクション名 */
 char g_action_name[DEFAULT_LENGTH] = "";
 /* PATH_INFO */
@@ -92,20 +91,20 @@ ActionType analysis_action()
     char admin_cgi_file_name[DEFAULT_LENGTH] = "";
     ActionType ret = ACTION_TYPE_NONE;
 
-    memset(g_project_name, 0, DEFAULT_LENGTH);
+    memset(g_project_code, 0, DEFAULT_LENGTH);
     memset(g_action_name, 0, DEFAULT_LENGTH);
     memset(g_path_info, 0, DEFAULT_LENGTH);
     d("************************************\n");
     d("REQUEST: %s%s\n", script_name, path_info);
     if (strlen(path_info) > 1) {
-        strncpy(g_project_name, path_info + 1, DEFAULT_LENGTH);
+        strncpy(g_project_code, path_info + 1, DEFAULT_LENGTH);
     } else {
         redirect_raw("top");
         return ret; /* ACTION_TYPE_NONE を返却する。 */
     }
-    if ((index = strchr(g_project_name, '/'))) {
+    if ((index = strchr(g_project_code, '/'))) {
         *index = '\0';
-        strncpy(g_action_name, index + 1, DEFAULT_LENGTH - (strlen(g_project_name) + 1));
+        strncpy(g_action_name, index + 1, DEFAULT_LENGTH - (strlen(g_project_code) + 1));
         if ((index = strchr(g_action_name, '/'))) {
             *index = '\0';
             /* 残りをpath_infoとする */
@@ -113,13 +112,13 @@ ActionType analysis_action()
         }
     }
     /* URLとして使われるプロジェクトID。URL encodeする。 */
-    url_encode((unsigned char*)g_project_name, (unsigned char*)g_project_name_4_url, DEFAULT_LENGTH);
+    url_encode((unsigned char*)g_project_code, (unsigned char*)g_project_code_4_url, DEFAULT_LENGTH);
 
     sprintf(index_cgi_file_name, "index.%s", get_ext(cgiScriptName));
     sprintf(admin_cgi_file_name, "admin.%s", get_ext(cgiScriptName));
     /* 実行するモードの判定 */
     if (strstr(script_name, index_cgi_file_name)) {
-        if (strcmp(g_project_name, "top") == 0) {
+        if (strcmp(g_project_code, "top") == 0) {
             d("actiontype top\n");
             ret = ACTION_TYPE_INDEX_TOP;
         } else {
@@ -127,8 +126,8 @@ ActionType analysis_action()
             ret = ACTION_TYPE_INDEX;
         }
     } else if (strstr(script_name, admin_cgi_file_name)) {
-        d("g_project_name: %s\n", g_project_name);
-        if (strcmp(g_project_name, "top") == 0) {
+        d("g_project_code: %s\n", g_project_code);
+        if (strcmp(g_project_code, "top") == 0) {
             d("actiontype admin top\n");
             ret = ACTION_TYPE_ADMIN_TOP;
         } else {
@@ -144,6 +143,7 @@ void exec_action()
     char action_name[DEFAULT_LENGTH];
     strcpy(action_name, g_action_name);
     for (a = get_actions(); a != NULL; a = a->next) {
+/*         d("action: %s %s\n", a->action_name, action_name); */
         if (!strcmp(action_name, a->action_name)) {
             d("=exec_action start: %s\n", a->action_name);
             a->action_func();
@@ -266,7 +266,7 @@ static cgiFormResultType cgiHtmlEscapeDataMultiLine(char *data, int len)
             } else {
                 char display_text[DEFAULT_LENGTH];
                 if (strlen(project_id) == 0) {
-                    strcpy(project_id, g_project_name_4_url);
+                    strcpy(project_id, g_project_code_4_url);
                     strcpy(display_text, ticket_id);
                 } else {
                     sprintf(display_text, "%s:%s", project_id, ticket_id);
@@ -519,7 +519,7 @@ void redirect(const char* path, const char* message)
         strcat(uri, "?message=");
         strcat(uri, parambuf);
     }
-    sprintf(redirecturi, "%s/%s%s", cgiScriptName, g_project_name, uri);
+    sprintf(redirecturi, "%s/%s%s", cgiScriptName, g_project_code, uri);
     o("Status: 302 Temporary Redirection\r\n");
     cgiHeaderLocation(redirecturi);
 }
@@ -553,7 +553,7 @@ void redirect_with_hook_messages(const char* path, const char* message, List* re
             i++;
         }
     }
-    sprintf(redirecturi, "%s/%s%s", cgiScriptName, g_project_name, uri);
+    sprintf(redirecturi, "%s/%s%s", cgiScriptName, g_project_code, uri);
     o("Status: 302 Temporary Redirection\r\n");
     cgiHeaderLocation(redirecturi);
 }
@@ -572,27 +572,9 @@ static cgiFormResultType csv_escape(char *data, int len)
 }
 void csv_field(char* src)
 {
-    iconv_t ic;
-    size_t src_size, dist_size, ret_len;
-    char* dist_a;
-    char* dist_p;
-    bool has_error = false;
-
-    src_size = strlen(src) + 1;
-    dist_size = src_size;  /* UTF-8からCP932なので、長さが短かくなることはない。そのためdist_sizeにも同じ長さを指定する。*/
-    dist_p = dist_a = xalloc(sizeof(char) * dist_size);
-    /* 文字コード変換処理 *          */
-    ic = iconv_open("CP932", "UTF-8");
-    ret_len = iconv(ic, &src, &src_size, &dist_p, &dist_size);
-    if (ret_len == (size_t)-1) {
-        d("iconv failed: %s", strerror(errno));
-        has_error = true;
-    }
     o("\"");
-    if (!has_error) csv_escape(dist_a, strlen(dist_a));
+    csv_escape(src, strlen(src));
     o("\"");
-    iconv_close(ic);
-    xfree(dist_a);
 }
 static cgiFormResultType cgiCssClassName(char *data, int len)
 {
@@ -698,4 +680,17 @@ char* get_ext(char* path)
     }
     return "";
 }
+void print_field_help()
+{
+    o(      "<div class=\"description\">\n"
+            "\t<ul>\n"
+            "\t\t<li>%s</li>\n"
+            "\t\t<li>%s</li>\n"
+            "\t\t<li>%s</li>\n"
+            "\t</ul>\n"
+            "</div>\n",
+            _("[ticket form syntax description1]"),
+            _("[ticket form syntax description2]"),
+            _("[ticket form syntax description3]"));
+}
 /* vim: set ts=4 sw=4 sts=4 expandtab fenc=utf-8: */
